@@ -7,7 +7,7 @@ import torch.optim as optim
 import os
 
 
-def local(dataset, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_epochs, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu'), **split):
+def run(dataset, batch_size, num_nodes, model, objective, optimizer, global_rounds, local_steps, device = torch.device('cuda' if torch.cuda.is_available() else 'cpu'), **split):
     dt = data_process(dataset)
     train_splited,test_splited = dt.split_dataset(num_nodes, split['split_para'], split['split_method'])
 
@@ -29,8 +29,8 @@ def local(dataset, batch_size, num_nodes, model, objective, optimizer, global_ro
         nodes[i].assign_objective(local_loss[i])
         # optim
         # nodes[i].assign_optim(optim.Adam(nodes[i].model.parameters()))
-        # nodes[i].assign_optim(optimizer(nodes[i].model.parameters()))
-        nodes[i].assign_optim(optim.SGD(nodes[i].model.parameters(), lr=0.001, momentum=0.9))
+        nodes[i].assign_optim(optimizer(nodes[i].model.parameters()))
+        # nodes[i].assign_optim(optim.SGD(nodes[i].model.parameters(), lr=0.001, momentum=0.9))
 
     # initialize parameters to nodes
     server.distribute(nodes, list(range(num_nodes)))
@@ -40,11 +40,9 @@ def local(dataset, batch_size, num_nodes, model, objective, optimizer, global_ro
         print('-------------------Global round %d start-------------------' % (i))
         # single-processing!
         for j in range(num_nodes):
-            nodes[j].local_update_steps(local_epochs, device)
+            nodes[j].local_update_steps(local_steps, device)
             nodes[j].local_test(device)
-        # server aggregation and distribution
-        # server.aggregate(nodes, list(range(num_nodes)), device)
-        # server.distribute(nodes, list(range(num_nodes)))
+        # test accuracy
         server.acc(nodes, list(range(num_nodes)))
 
     # log
