@@ -79,8 +79,9 @@ class data_process:
                 lens_list.append(len(dataset)-sum(lens_list))
                 return random_split(dataset, lens_list)
             else:
-                self.train_dataset.targets = torch.tensor(self.train_dataset.targets)
-                self.test_dataset.targets = torch.tensor(self.test_dataset.targets)
+                if torch.is_tensor(self.train_dataset.targets)==False:
+                    self.train_dataset.targets = torch.tensor(self.train_dataset.targets)
+                    self.test_dataset.targets = torch.tensor(self.test_dataset.targets)
                 labels = torch.unique(self.train_dataset.targets)
                 train_label_size = self.train_dataset.targets.bincount()
                 test_label_size = self.test_dataset.targets.bincount()
@@ -136,12 +137,12 @@ class data_process:
                 # plt.title("Data distribution of dataset")
                 plt.legend()
                 mpl.rcParams['figure.dpi'] = 300
-                plt.show()
+                # plt.show()
                 return train_splited, test_splited
 
 
 def log(file_name, nodes, server):
-    local_file = './log/' + file_name + "_" + d.datetime.now().strftime("%Y%m%d_%H%M%S") + ".pkl"
+    local_file = './log/' + file_name + "_" + d.datetime.now().strftime("%m%d_%H%M%S")+'_'+str(np.random.choice(10**3)) + ".pkl"
     log = {}
     log['node'] = {}
     for i in range(len(nodes)):
@@ -158,8 +159,9 @@ def log(file_name, nodes, server):
 
     # read
     if os.path.exists(local_file):
-        log = pickle.load(open(local_file, 'rb'))
-        print(log)
+        with open(local_file, 'rb') as f:
+            log = pickle.load(f)
+            print(log)
 
 # dt = data_process('mnist')
 # # dt.split_dataset(50, 2, method='class')
